@@ -5,6 +5,7 @@ import time
 from typing import Callable, Dict, Optional
 
 from colorama import Back, Fore, Style
+
 from mltraq.extras.environment import is_tty
 from mltraq.options import options
 
@@ -50,7 +51,7 @@ def init_logging():
         # duplicate log entries to stdout.
         logging.getLogger().handlers.clear()
 
-    # Get logger for MLTRAQ and clear the handlers.
+    # Get logger for MLtraq and clear the handlers.
     logger = logging.getLogger("mltraq")
     logger.handlers.clear()
     logger.setLevel(getattr(logging, options.get("logging.level")))
@@ -186,7 +187,7 @@ def default_exception_handler(func: Callable) -> Callable:
             try:
                 return func(*args, **kwargs)
             except (KeyboardInterrupt, TypeError, Exception) as e:
-                if type(e) == KeyboardInterrupt:
+                if isinstance(e, KeyboardInterrupt):
                     return fatal("Keyboard interrupt.")
                 else:
                     return fatal(f"{compact_exception_message(e)}.")
